@@ -5,13 +5,14 @@ OC.L10N.register(
     "All contacts" : "Alle kontakte",
     "Details" : "Details",
     "A contacts app for Nextcloud" : "’n Kontakte-toep vir Nextcloud",
+    "Invalid image" : "Ongeldige beeld",
     "Loading" : "Laai tans..",
     "Name" : "Naam",
     "Company" : "Maatskappy",
     "Title" : "Titel",
     "Download" : "Laai Af",
     "Delete" : "Skrap",
-    "Addressbook" : "Adresboek",
+    "Cancel" : "Kanselleer",
     "Groups" : "Groepe",
     "New contact" : "Nuwe kontak",
     "Select type" : "Kies tipe",
