@@ -5,16 +5,18 @@ OC.L10N.register(
     "All contacts" : "كل الجهات",
     "Details" : "التفاصيل",
     "Add a new picture" : "إضافة صورة جديدة",
-    "Upload a new picture" : "تحميل صورة جديدة",
-    "Delete picture" : "حذف الصورة",
     "Download picture" : "تنزيل الصورة",
+    "Delete picture" : "حذف الصورة",
+    "Upload a new picture" : "تحميل صورة جديدة",
+    "Invalid image" : "الصورة غير صالحة",
     "Loading" : "Loading",
     "Name" : "الاسم",
     "Company" : "الشركة",
     "Title" : "العنوان",
     "Download" : "تحميل",
     "Delete" : "حذف",
-    "Addressbook" : "دفتر العناوين",
+    "Cancel" : "إلغاء",
+    "Address book" : "دفتر العناوين",
     "Groups" : "مجموعات",
     "New contact" : "جهة إتصال جديدة",
     "No errors" : "لا توجد أخطاء",
@@ -26,8 +28,6 @@ OC.L10N.register(
     "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "can edit" : "يمكن التعديل",
-    "Importing into" : "إستيراد إلى",
-    "Import into" : "إستيراد إلى",
     "Address book name" : "اسم دفتر العناوين",
     "First name" : "الإسم",
     "Last name" : "اللقب",
