@@ -4,11 +4,14 @@ OC.L10N.register(
     "Contacts" : "Contautos",
     "All contacts" : "Tolos contautos",
     "Details" : "Detalles",
+    "Invalid image" : "Imaxe non válida",
     "Loading" : "Cargando",
     "Name" : "Nome",
     "Title" : "Títulu",
     "Download" : "Baxar",
     "Delete" : "Desaniciar",
+    "Cancel" : "Encaboxar",
+    "Address book" : "Llibreta de direiciones",
     "Groups" : "Grupos",
     "New contact" : "Contautu nuevu",
     "No results" : "Ensin resultaos",
