@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Contacts" : "Əlaqələr",
     "Details" : "Detallar",
+    "Invalid image" : "Yalnış şəkil",
     "Loading" : "Loading",
     "Name" : "Ad",
     "Title" : "Başlıq",
     "Download" : "Yüklə",
     "Delete" : "Sil",
+    "Cancel" : "Dayandır",
     "Groups" : "Qruplar",
     "Rename" : "Adı dəyiş",
     "Enabled" : "İşə salınıb",
