@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Contacts" : "পরিচিতজন",
     "Details" : "বিসতারিত",
+    "Invalid image" : "অবৈধ চিত্র",
     "Loading" : "Loading",
     "Name" : "নাম",
     "Title" : "শিরোনাম",
     "Download" : "ডাউনলোড",
     "Delete" : "মুছে",
+    "Cancel" : "বাতির",
     "Groups" : "গোষ্ঠীসমূহ",
     "New contact" : "নতুন ঠিকানা",
     "Rename" : "পূনঃনামকরণ",
