@@ -2,11 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontakti",
+    "Invalid image" : "Nevažeća datoteka",
     "Loading" : "Loading",
     "Name" : "Ime",
     "Title" : "Naslov",
     "Download" : "Preuzmi",
     "Delete" : "Obriši",
+    "Cancel" : "Otkaži",
     "Groups" : "Grupe",
     "New contact" : "Novi kontakt",
     "Rename" : "Preimenuj",
