@@ -10,9 +10,10 @@ OC.L10N.register(
     "Add new property" : "Añadir nueva propiedad",
     "Choose property type" : "Elija el tipo de propiedad",
     "Add a new picture" : "Agregar una nueva foto",
-    "Upload a new picture" : "Subir una nueva imagen",
     "Choose from files" : "Elige entre archivos",
     "Download picture" : "Descargar imágen",
+    "Upload a new picture" : "Subir una nueva imagen",
+    "Invalid image" : "Imagen inválida",
     "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
     "No contact selected" : "Contacto no seleccionado",
     "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
@@ -23,13 +24,12 @@ OC.L10N.register(
     "Download" : "Descargar",
     "Generate QR Code" : "Generar código QR",
     "Delete" : "Borrar",
+    "Cancel" : "Cancelar",
     "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
-    "Addressbook" : "Directorio",
     "Groups" : "Grupos",
     "New contact" : "Nuevo contacto",
-    "Importing {total} contacts into" : "Importando {total} contactos a",
     "No errors" : "Sin errores",
     "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
     "Select type" : "Seleccionar tipo",
@@ -44,23 +44,14 @@ OC.L10N.register(
     "Copied" : "Copiado",
     "Can not copy" : "No se puede copiar",
     "Copy link" : "Copiar enlace",
-    "Enabled toggle of addressbook was not successful." : "La alternancia habilitada de la libreta de direcciones no tuvo éxito.",
-    "This will delete the addressbook and every contacts within it" : "Esto eliminará la libreta de direcciones y todos los contactos dentro de ella.",
     "Delete {addressbook} ?" : "¿Borrar {addressbook} ?",
-    "Deletion of addressbook was not successful." : "La eliminación de la libreta de direcciones no tuvo éxito.",
-    "Renaming of addressbook was not successful." : "El cambio de nombre de la libreta de direcciones no tuvo éxito.",
-    "Addressbook copied to clipboard" : "Libreta de direcciones copiada al portapapeles",
-    "Addressbook was not copied to clipboard." : "La libreta de direcciones no se copió al portapapeles.",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "No hay usuarios ni grupos.",
     "can edit" : "poder editar",
     "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
     "Unable to change permissions." : "No se pueden cambiar los permisos.",
-    "Importing into" : "Importando en",
-    "Import into" : "Importar en",
     "Importing is disabled because there are no address books available" : "La importación está deshabilitada porque no hay libretas de direcciones disponibles",
     "Address book name" : "Nombre de la libreta de direcciones",
-    "An error occurred, unable to create the addressbook." : "Se produjo un error, no se puede crear la libreta de direcciones.",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre para mostrar",
