@@ -4,11 +4,14 @@ OC.L10N.register(
     "Contacts" : "Kontaktid",
     "All contacts" : "Kõik kontaktid",
     "Details" : "Üksikasjad",
+    "Invalid image" : "Vigane pilt",
     "Loading" : "Laadimine",
     "Name" : "Nimi",
     "Title" : "Pealkiri",
     "Download" : "Lae alla",
     "Delete" : "Kustuta",
+    "Cancel" : "Loobu",
+    "Address book" : "Aadressiraamat",
     "Groups" : "Grupid",
     "New contact" : "Uus kontakt",
     "No results" : "Vasteid ei leitud",
@@ -18,9 +21,8 @@ OC.L10N.register(
     "Disabled" : "Keelatud",
     "Copy link" : "Kopeeri link",
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
+    "No users or groups" : "Ei ole kasutajaid või gruppe",
     "can edit" : "saab redigeerida",
-    "Importing into" : "Importimine sisse",
-    "Import into" : "import sisse",
     "Address book name" : "Aadressiraamatu nimi",
     "First name" : "Eesnimi",
     "Last name" : "Perekonnanimi",
@@ -78,6 +80,7 @@ OC.L10N.register(
     "Female" : "Naine",
     "Male" : "Mees",
     "None" : "Pole",
-    "Unknown" : "Teadmata"
+    "Unknown" : "Teadmata",
+    "An error occurred" : "Tekkis tõrge"
 },
 "nplurals=2; plural=(n != 1);");
