@@ -9,10 +9,12 @@ OC.L10N.register(
     "Add new property" : "Lisää uusi ominaisuus",
     "Choose property type" : "Valitse ominaisuuden tyyppi",
     "Add a new picture" : "Lisää uusi kuva",
-    "Upload a new picture" : "Lähetä uusi kuva",
+    "Upload new picture" : "Lähetä uusi kuva",
     "Choose from files" : "Valitse tiedostoista",
-    "Delete picture" : "Poista kuva",
     "Download picture" : "Lataa kuva",
+    "Delete picture" : "Poista kuva",
+    "Upload a new picture" : "Lähetä uusi kuva",
+    "Invalid image" : "Virheellinen kuva",
     "Image is too big (max 1MB)." : "Kuva on liian suuri (enintään 1 Mt).",
     "Pick an avatar" : "Valitse avatar",
     "Error while processing the picture." : "Virhe kuvan käsittelyn aikana.",
@@ -23,17 +25,25 @@ OC.L10N.register(
     "Company" : "Yritys",
     "Title" : "Nimeke",
     "Download" : "Lataa",
+    "Clone contact" : "Kloonaa yhteystieto",
     "Generate QR Code" : "Luo QR-koodi",
     "Delete" : "Poista",
+    "Pick an address book" : "Valitse osoitekirja",
+    "Select address book" : "Valitse osoitekirja",
+    "Cancel" : "Peruuta",
     "This contact is not yet synced. Edit it to save it to the server." : "Tätä yhteystietoa ei ole vielä synkronoitu. Muokkaa yhteystietoa tallentaaksesi sen palvelimelle.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
-    "Addressbook" : "Osoitekirja",
+    "Address book" : "Osoitekirja",
     "Groups" : "Ryhmät",
     "New contact" : "Uusi yhteystieto",
-    "Deleting the contact in {countdown} seconds" : "Poistetaan yhteystieto {countdown} sekunnin kuluttua",
+    "Syntax error. Cannot open the contact." : "Syntaksivirhe. Yhteystietoa ei voi avata.",
+    "An error occurred while trying to move the contact" : "Yhteystietoa siirtäessä tapahtui virhe",
+    "An error occurred while trying to copy the contact" : "Yhteystietoa kopioitaessa tapahtui virhe",
     "No errors" : "Ei virheitä",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} virheellinen yhteystieto","{failedCount} virheellistä yhteystietoa"],
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Tuodaan %n yhteystieto osoitekirjaan {addressbook}","Tuodaan %n yhteystietoa osoitekirjaan {addressbook}"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["%n yhteystiedon tuominen osoitekirjaan {addressbook} valmistui","%n yhteystiedon tuominen osoitekirjaan {addressbook} onnistui"],
     "Select type" : "Valitse tyyppi",
     "Select Date" : "Valitse päivä",
     "Add contact in group" : "Lisää yhteystieto ryhmään",
@@ -46,22 +56,25 @@ OC.L10N.register(
     "Copied" : "Kopioitu",
     "Can not copy" : "Ei voida kopioida",
     "Copy link" : "Kopioi linkki",
-    "This will delete the addressbook and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
+    "This will delete the address book and every contacts within it" : "Tämä poistaa osoitekirjan ja kaikki siinä olevat yhteystiedot",
     "Delete {addressbook} ?" : "Poistetaanko {addressbook} ?",
-    "Deletion of addressbook was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
-    "Renaming of addressbook was not successful." : "Osoitekirja nimen muuttaminen ei onnistunut.",
-    "Addressbook copied to clipboard" : "Osoitekirja kopioitu leikepöydälle",
-    "Addressbook was not copied to clipboard." : "Osoitekirjaa ei kopioitu leikepöydälle.",
+    "Deletion of address book was not successful." : "Osoitekirjan poistaminen ei onnistunut.",
+    "Renaming of address book was not successful." : "Osoitekirjan nimeäminen uudelleen ei onnistunut.",
+    "Address book copied to clipboard" : "Osoitekirja kopioitu leikepöydälle",
+    "Address book was not copied to clipboard." : "Osoitekirjaa ei kopioitu leikepöydälle.",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["Jaettu {num} entiteetin kanssa","Jaettu {num} entiteetin kanssa"],
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "can edit" : "voi muokata",
     "Unable to delete the share." : "Jakoa ei voitu poistaa.",
     "Unable to change permissions." : "Käyttöoikeuksia ei voitu muuttaa.",
-    "Import into" : "Tuo kirjaan",
+    "Import contacts" : "Tuo yhteystietoja",
+    "Select local file" : "Valitse paikallinen tiedosto",
+    "Import from files" : "Tuo tiedostoista",
     "Importing is disabled because there are no address books available" : "Tuonti on pois käytöstä, koska osoitekirjoja ei ole käytettävissä",
+    "Choose a vCard file to import" : "Valitse tuotava vCard-tiedosto",
     "Address book name" : "Osoitekirjan nimi",
-    "An error occurred, unable to create the addressbook." : "Tapahtui virhe, osoitekirjaa ei voitu luoda.",
+    "An error occurred, unable to create the address book." : "Tapahtui virhe, osoitekirjaa ei voitu luoda.",
     "First name" : "Etunimi",
     "Last name" : "Sukunimi",
     "Display name" : "Näyttönimi",
@@ -90,6 +103,7 @@ OC.L10N.register(
     "Country" : "Maa",
     "Birthday" : "Syntymäpäivä",
     "Anniversary" : "Vuosipäivä",
+    "The date of marriage, or equivalent, of this contact" : "Hääpäivä tai vastaava",
     "Date of death" : "Kuolinpäivä",
     "Email" : "Sähköpostiosoite",
     "Instant messaging" : "Pikaviestintä",
@@ -119,6 +133,8 @@ OC.L10N.register(
     "Colleague" : "Työkaveri",
     "Manager" : "Esimies",
     "Assistant" : "Avustaja",
+    "Related" : "Liittyy",
+    "Contact" : "Yhteystieto",
     "Emergency" : "Hätä",
     "Co-worker" : "Työkaveri",
     "Gender" : "Sukupuoli",
