@@ -4,11 +4,13 @@ OC.L10N.register(
     "Contacts" : "Contactos",
     "All contacts" : "Tote contactos",
     "Details" : "Detalios",
+    "Invalid image" : "Imagine invalide",
     "Loading" : "Loading",
     "Name" : "Nomine",
     "Title" : "Titulo",
     "Download" : "Discargar",
     "Delete" : "Deler",
+    "Cancel" : "Cancellar",
     "Groups" : "Gruppos",
     "New contact" : "Nove contacto",
     "Rename" : "Renominar",
