@@ -4,11 +4,13 @@ OC.L10N.register(
     "Contacts" : "Kontak",
     "All contacts" : "Semua kontak",
     "Details" : "Detil",
+    "Invalid image" : "Gambar tidak sah",
     "Loading" : "Memuat",
     "Name" : "Nama",
     "Title" : "Judul",
     "Download" : "Unduh",
     "Delete" : "Hapus",
+    "Cancel" : "Membatalkan",
     "Groups" : "Grup",
     "New contact" : "Kontak baru",
     "No results" : "Tidak ada hasil",
