@@ -11,10 +11,11 @@ OC.L10N.register(
     "Add new property" : "新しいプロパティを追加する",
     "Choose property type" : "プロパティの種類を選択",
     "Add a new picture" : "画像を追加",
-    "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from files" : "ファイルから選択",
-    "Delete picture" : "画像を削除",
     "Download picture" : "画像をダウンロード",
+    "Delete picture" : "画像を削除",
+    "Upload a new picture" : "新しい写真をアップロードする",
+    "Invalid image" : "無効な画像",
     "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
     "Pick an avatar" : "アバターを選択",
     "Error while processing the picture." : "画像の加工中にエラーが発生しました",
@@ -28,16 +29,14 @@ OC.L10N.register(
     "Download" : "ダウンロード",
     "Generate QR Code" : "QRコードを生成",
     "Delete" : "削除",
+    "Cancel" : "キャンセル",
     "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存してください。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
-    "Addressbook" : "アドレス帳",
+    "Address book" : "連絡帳",
     "Groups" : "グループ",
     "New contact" : "新しい連絡先",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
-    "Deleting the contact in {countdown} seconds" : "{countdown}秒後に連絡先を削除します",
-    "Done importing {total} contacts into" : " {total} 数の連絡先をインポートしました",
-    "Importing {total} contacts into" : "連絡先を {total} にインポートしています",
     "No errors" : "エラーはありません",
     "Open your browser console for more details" : "詳細はブラウザコンソールを開きます",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount}件の連絡先の誤り"],
@@ -53,24 +52,15 @@ OC.L10N.register(
     "Copied" : "コピーしました",
     "Can not copy" : "コピーできません",
     "Copy link" : "リンクをコピー",
-    "Enabled toggle of addressbook was not successful." : "アドレス帳の有効なトグルが成功しませんでした。",
-    "This will delete the addressbook and every contacts within it" : "アドレス帳とすべての連絡先が削除されます。",
     "Delete {addressbook} ?" : "{アドレス帳}を削除しますか？",
-    "Deletion of addressbook was not successful." : "アドレス帳の削除に失敗しました。",
-    "Renaming of addressbook was not successful." : "アドレス帳の名前を変更できませんでした。",
-    "Addressbook copied to clipboard" : "アドレス帳をクリップボードにコピー",
-    "Addressbook was not copied to clipboard." : "アドレス帳はクリップボードにコピーされませんでした。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "No users or groups" : "ユーザーまたはグループはありません",
     "can edit" : "編集を許可",
     "Unable to delete the share." : "共有を解除できません。",
     "Unable to change permissions." : "権限を変更できません。",
-    "Importing into" : "インポート",
-    "Import into" : "インポート",
     "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
     "Address book name" : "アドレス帳名",
-    "An error occurred, unable to create the addressbook." : "エラーが発生し、アドレス帳を作成できません。",
     "First name" : "名",
     "Last name" : "姓",
     "Display name" : "表示名",
