@@ -4,11 +4,14 @@ OC.L10N.register(
     "Contacts" : "კონტაქტები",
     "All contacts" : "ყველა კონტაქტი",
     "Details" : "დეტალები",
+    "Invalid image" : "არასწორი სურათი",
     "Loading" : "იტვირთება",
     "Name" : "სახელი",
     "Title" : "სათაური",
     "Download" : "ჩამოტვირთვა",
     "Delete" : "გაუქმება",
+    "Cancel" : "უარყოფა",
+    "Address book" : "მისამართების წიგნი",
     "Groups" : "ჯგუფები",
     "New contact" : "ახალი კონტაქტი",
     "No results" : "შედეგები არაა",
@@ -19,8 +22,6 @@ OC.L10N.register(
     "Copy link" : "ბმულის კოპირება",
     "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
     "can edit" : "შეუძლია შეცვლა",
-    "Importing into" : "იმპორტირება",
-    "Import into" : "იმპორტირება",
     "Address book name" : "მისამართების წიგნის სახელი",
     "First name" : "სახელი",
     "Last name" : "გვარი",
