@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Contacts" : "ទំនាក់​ទំនង",
     "Details" : "ព័ត៌មាន​លម្អិត",
+    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
     "Loading" : "Loading",
     "Name" : "ឈ្មោះ",
     "Title" : "ចំណងជើង",
     "Download" : "ទាញយក",
     "Delete" : "លុប",
+    "Cancel" : "បោះបង់",
     "Groups" : "ក្រុ",
     "Rename" : "ប្ដូរ​ឈ្មោះ",
     "Enabled" : "បាន​បើក",
