@@ -1,11 +1,13 @@
 OC.L10N.register(
     "contacts",
     {
+    "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
     "Loading" : "Loading",
     "Name" : "﻿ಹೆಸರು",
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "Delete" : "﻿ಅಳಿಸಿ",
+    "Cancel" : "﻿ರದ್ದು",
     "Groups" : "﻿ಗುಂಪುಗಳು",
     "Rename" : "﻿ಮರುಹೆಸರಿಸು",
     "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
