@@ -10,10 +10,11 @@ OC.L10N.register(
     "Add new property" : "새 속성 추가",
     "Choose property type" : "속성 종류 선택",
     "Add a new picture" : "새 그림 추가",
-    "Upload a new picture" : "새 그림 업로드",
     "Choose from files" : "파일에서 선택",
-    "Delete picture" : "그림 삭제",
     "Download picture" : "그림 다운로드",
+    "Delete picture" : "그림 삭제",
+    "Upload a new picture" : "새 그림 업로드",
+    "Invalid image" : "잘못된 사진",
     "Image is too big (max 1MB)." : "그림이 너무 큽니다(최대 1MB).",
     "Pick an avatar" : "아바타 선택",
     "Error while processing the picture." : "그림을 처리하는 중 오류가 발생했습니다.",
@@ -26,16 +27,14 @@ OC.L10N.register(
     "Download" : "다운로드",
     "Generate QR Code" : "QR 코드 생성",
     "Delete" : "삭제",
+    "Cancel" : "취소",
     "This contact is not yet synced. Edit it to save it to the server." : "이 연락처를 동기화하지 않았습니다. 편집하면 서버에 저장합니다.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
-    "Addressbook" : "주소록",
+    "Address book" : "주소록",
     "Groups" : "그룹",
     "New contact" : "새 연락처",
     "Syntax error. Cannot open the contact." : "문법 오류입니다. 연락처를 열 수 없습니다.",
-    "Deleting the contact in {countdown} seconds" : "{countdown}초 후 연락처 삭제",
-    "Done importing {total} contacts into" : "연락처 {total}개 가져오기 완료",
-    "Importing {total} contacts into" : "연락처 {total}개 가져오는 중",
     "No errors" : "오류 없음",
     "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여십시오",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["잘못된 연락처 {failedCount}개"],
@@ -51,24 +50,15 @@ OC.L10N.register(
     "Copied" : "복사됨",
     "Can not copy" : "복사할 수 없음",
     "Copy link" : "링크 복사",
-    "Enabled toggle of addressbook was not successful." : "주소록 사용 여부를 전환할 수 없습니다.",
-    "This will delete the addressbook and every contacts within it" : "주소록과 포함된 모든 연락처를 삭제합니다",
     "Delete {addressbook} ?" : "{addressbook}을(를) 삭제하시겠습니까?",
-    "Deletion of addressbook was not successful." : "주소록을 삭제할 수 없습니다.",
-    "Renaming of addressbook was not successful." : "주소록의 이름을 변경할 수 없습니다.",
-    "Addressbook copied to clipboard" : "주소록을 클립보드에 복사함",
-    "Addressbook was not copied to clipboard." : "주소록을 클립보드에 복사할 수 없습니다.",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}명과 공유함"],
     "Share with users or groups" : "사용자 및 그룹과 공유",
     "No users or groups" : "사용자나 그룹 없음",
     "can edit" : "편집 가능",
     "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
     "Unable to change permissions." : "권한을 변경할 수 없습니다.",
-    "Importing into" : "다음으로 가져오는 중",
-    "Import into" : "다음으로 가져오기",
     "Importing is disabled because there are no address books available" : "주소록을 찾을 수 없어서 가져올 수 없습니다.",
     "Address book name" : "주소록 이름",
-    "An error occurred, unable to create the addressbook." : "오류가 발생하여 주소록을 만들 수 없습니다.",
     "First name" : "이름",
     "Last name" : "성",
     "Display name" : "표시 이름",
