@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Contacts" : "Kontakter",
     "Details" : "Detailer",
+    "Invalid image" : "Ongülteg d'Bild",
     "Loading" : "Loading",
     "Name" : "Numm",
     "Title" : "Titel",
     "Download" : "Eroflueden",
     "Delete" : "Läschen",
+    "Cancel" : "Ofbriechen",
     "Groups" : "Gruppen",
     "Rename" : "Ëmbenennen",
     "Enabled" : "Aktivéiert",
