@@ -4,11 +4,13 @@ OC.L10N.register(
     "Contacts" : "Харилцагчид",
     "All contacts" : "Бүх харилцагчид",
     "Details" : "Дэлгэрэнгүй",
+    "Invalid image" : "буруу зураг",
     "Loading" : "Loading",
     "Name" : "Нэр",
     "Title" : "Цол/Албан тушаал",
     "Download" : "Татаж авах",
     "Delete" : "Устгах",
+    "Cancel" : "болиулах",
     "Groups" : "Багууд",
     "New contact" : "Шинэ харилцагч",
     "No results" : "Үр дүн байхгүй",
