@@ -9,6 +9,7 @@ OC.L10N.register(
     "Add new property" : "Legg til felt",
     "Choose property type" : "Velg felttype",
     "Upload a new picture" : "Last opp et nytt bilde",
+    "Invalid image" : "Ugyldig bilde",
     "Image is too big (max 1MB)." : "Bildet er for stort (opptil 1MB).",
     "No contact selected" : "Ingen kontakt valgt",
     "Select a contact on the list to begin" : "Velg en kontakt fra listen for å begynne",
@@ -18,14 +19,14 @@ OC.L10N.register(
     "Title" : "Tittel",
     "Download" : "Last ned",
     "Delete" : "Slett",
+    "Cancel" : "Avbryt",
     "This contact is not yet synced. Edit it to save it to the server." : "Denne kontakt er enda ikke synkronisert. Rediger den for å lagre den på serveren.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du prøvde å redigere, har blitt endret. Vennligst oppdater manuelt. Ytterligere endringer vil ikke kunne lagres.",
-    "Addressbook" : "Addressebok",
+    "Address book" : "Adressebok",
     "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
     "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
-    "Importing {total} contacts into" : "Importerer {total} kontakter til",
     "No errors" : "Ingen feil",
     "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} kontakt med feil","{failedCount} kontakter med feil"],
@@ -41,18 +42,11 @@ OC.L10N.register(
     "Copied" : "Kopiert",
     "Can not copy" : "Kan ikke kopiere",
     "Copy link" : "Kopier lenke",
-    "This will delete the addressbook and every contacts within it" : "Dette vil slette addresseboken og kontaktene som hører til",
     "Delete {addressbook} ?" : "Slette {addressbook} ?",
-    "Deletion of addressbook was not successful." : "Sletting av addressebok mislyktes",
-    "Renaming of addressbook was not successful." : "Adresseboken kunne ikke omdøpes.",
-    "Addressbook copied to clipboard" : "Adresseboken ble kopiert til utklippstavlen",
-    "Addressbook was not copied to clipboard." : "Adresseboken ble ikke kopiert til utklippstavlen",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan redigere",
     "Unable to delete the share." : "Kan ikke slette delingen.",
-    "Importing into" : "Importerer til",
-    "Import into" : "Importer inn i",
     "Address book name" : "Adresseboksnavn",
     "First name" : "Fornavn",
     "Last name" : "Etternavn",
