@@ -3,11 +3,13 @@ OC.L10N.register(
     {
     "Contacts" : "Kontaktar",
     "Details" : "Detaljar",
+    "Invalid image" : "Ugyldig bilete",
     "Loading" : "Loading",
     "Name" : "Namn",
     "Title" : "Tittel",
     "Download" : "Last ned",
     "Delete" : "Ta bort",
+    "Cancel" : "Avbryt",
     "Groups" : "Grupper",
     "Last modified" : "Siste endra",
     "Rename" : "Gje nytt namn",
