@@ -2,9 +2,11 @@ OC.L10N.register(
     "contacts",
     {
     "Details" : "معلومات",
+    "Invalid image" : "انځور سم نه دی",
     "Name" : "نوم",
     "Download" : "ښکته کول",
     "Delete" : "ړنګول",
+    "Cancel" : "پرېښول",
     "Groups" : "ګروپونه",
     "Rename" : "نوم بدلول",
     "Copy link" : "لېنک کاپي کول",
