@@ -2,11 +2,13 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "සබඳතා",
+    "Invalid image" : "පින්තුරය දෝෂ සහිතයි",
     "Loading" : "Loading",
     "Name" : "නම",
     "Title" : "මාතෘකාව",
     "Download" : "බාන්න",
     "Delete" : "ඉවත් කරන්න",
+    "Cancel" : "අවලංගු කරන්න",
     "Groups" : "කණ්ඩායම්",
     "Rename" : "නැවත නම් කරන්න",
     "can edit" : "සංස්කරණය කළ හැක",
