@@ -10,10 +10,11 @@ OC.L10N.register(
     "Add new property" : "Shto karakteristikë të re",
     "Choose property type" : "Zgjidh llojin e  karakteristikës",
     "Add a new picture" : "Shto një foto të re",
-    "Upload a new picture" : "Ngarko një foto të re",
     "Choose from files" : "Zgjidh nga skedarët",
-    "Delete picture" : "Fshi foton",
     "Download picture" : "Shkarko foton",
+    "Delete picture" : "Fshi foton",
+    "Upload a new picture" : "Ngarko një foto të re",
+    "Invalid image" : "Figurë e pavlefshme",
     "Image is too big (max 1MB)." : "Imazhi është shumë i madh (maksimumi 1MB).",
     "Pick an avatar" : "Zgjidh një avatar",
     "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
@@ -27,16 +28,14 @@ OC.L10N.register(
     "Download" : "Shkarko",
     "Generate QR Code" : "Gjeneroni Kodin QR",
     "Delete" : "Fshije",
+    "Cancel" : "Anullo",
     "This contact is not yet synced. Edit it to save it to the server." : "Ky kontakt nuk është sinkronizuar akoma. Përditësojeni atë për ta ruajtur në server.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
-    "Addressbook" : "Libri i adresave",
+    "Address book" : "Libri i adresave",
     "Groups" : "Grupe",
     "New contact" : "Kontakt i ri",
     "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
-    "Deleting the contact in {countdown} seconds" : "Duke fshirë kontaktin në {countdown}  sekonda",
-    "Done importing {total} contacts into" : "Importimi i {total} kontakteve u krye në ",
-    "Importing {total} contacts into" : "Duke importuar {total} kontakte në ",
     "No errors" : "Nuk ka gabime",
     "Open your browser console for more details" : "Hapni panelin e komandimit të shfletuesit tuaj për më shumë detaje",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} kontakt me gabime","{failedCount} kontakte me gabime"],
@@ -51,8 +50,6 @@ OC.L10N.register(
     "Copy link" : "Kopjo linkun",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
     "can edit" : "mund të modifikoni",
-    "Importing into" : "Duke u importuar në",
-    "Import into" : "Importo tek ",
     "Address book name" : "Emër libri adresash",
     "First name" : "Emër",
     "Last name" : "Mbiemër",
