@@ -4,11 +4,13 @@ OC.L10N.register(
     "Contacts" : "ข้อมูลผู้ติดต่อ",
     "All contacts" : "รายชื่อทั้งหมด",
     "Details" : "รายละเอียด",
+    "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "Loading" : "Loading",
     "Name" : "ชื่อ",
     "Title" : "ชื่อเรื่อง",
     "Download" : "ดาวน์โหลด",
     "Delete" : "ลบ",
+    "Cancel" : "ยกเลิก",
     "Groups" : "กลุ่ม",
     "New contact" : "รายชื่อผุ้ติดต่อใหม่",
     "Rename" : "เปลี่ยนชื่อ",
