@@ -7,10 +7,11 @@ OC.L10N.register(
     "Add new property" : "Додати нову властивість",
     "Choose property type" : "Обрати тип властивості",
     "Add a new picture" : "Додати нове зображення",
-    "Upload a new picture" : "Завантажити нове зображення",
     "Choose from files" : "Обрати з файлу",
-    "Delete picture" : "Видалити зображення",
     "Download picture" : "Завантажити зображення",
+    "Delete picture" : "Видалити зображення",
+    "Upload a new picture" : "Завантажити нове зображення",
+    "Invalid image" : "Невірне зображення",
     "Image is too big (max 1MB)." : "Зображення завелике (максимум 1МБ).",
     "Pick an avatar" : "Оберіть аватарку",
     "Error while processing the picture." : "Помилка під час обробки зображення.",
@@ -23,18 +24,19 @@ OC.L10N.register(
     "Download" : "Завантажити",
     "Generate QR Code" : "Створити QR код",
     "Delete" : "Видалити",
-    "Addressbook" : "Адресна книга",
+    "Cancel" : "Скасувати",
+    "Address book" : "Адресна книга",
     "Groups" : "Групи",
     "New contact" : "Новий контакт",
+    "Select Date" : "Вкажіть дату",
     "No results" : "Немає результатів",
     "Rename" : "Перейменувати",
     "Enabled" : "Увімкнено",
     "Disabled" : "Вимкнено",
     "Copy link" : "Копіювати посилання",
     "Share with users or groups" : "Поділитися з користувачем або групою",
+    "No users or groups" : "Жодного користувача або групм",
     "can edit" : "може редагувати",
-    "Importing into" : "Імпортування до",
-    "Import into" : "Імпортувати до",
     "Address book name" : "Назва адресної книги",
     "First name" : "Ім'я",
     "Last name" : "Прізвище",
