@@ -2,10 +2,12 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontaktlar",
+    "Invalid image" : "Tasdiqlanmagan tasvir",
     "Loading" : "Yuklanmoqda",
     "Name" : "Ism...",
     "Download" : "Yuklab oling",
     "Delete" : "O'chir",
+    "Cancel" : "Bekor qilish",
     "Groups" : "Guruhlar",
     "Rename" : "Nomni o'zgartiring",
     "Notes" : "Eslatmalar",
