@@ -11,10 +11,12 @@ OC.L10N.register(
     "Add new property" : "新增属性",
     "Choose property type" : "选择属性类型",
     "Add a new picture" : "添加一张新图片",
-    "Upload a new picture" : "上传一张新的图片",
+    "Upload new picture" : "上传新的图片",
     "Choose from files" : "从文件中选择",
-    "Delete picture" : "删除图片",
     "Download picture" : "下载图片",
+    "Delete picture" : "删除图片",
+    "Upload a new picture" : "上传一张新的图片",
+    "Invalid image" : "无效的图像",
     "Image is too big (max 1MB)." : "图片过大(最大1MB)",
     "Pick an avatar" : "选择一个头像",
     "Error while processing the picture." : "处理图片时出错。",
@@ -28,19 +30,19 @@ OC.L10N.register(
     "Download" : "下载",
     "Generate QR Code" : "生成二维码",
     "Delete" : "删除",
+    "Cancel" : "取消",
     "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
-    "Addressbook" : "地址簿",
+    "Address book" : "地址簿",
     "Groups" : "群组",
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
-    "Deleting the contact in {countdown} seconds" : "正在删除联系人, 剩余 {countdown} 秒",
-    "Done importing {total} contacts into" : "导入 {total} 个联系人",
-    "Importing {total} contacts into" : "正在导入 {total} 个联系人",
     "No errors" : "没有错误",
     "Open your browser console for more details" : "打开浏览器控制台以获取更多详细信息",
     "_{failedCount} faulty contact_::_{failedCount} faulty contacts_" : ["{failedCount} 个有错误的联系人"],
+    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
+    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
@@ -53,24 +55,19 @@ OC.L10N.register(
     "Copied" : "已复制",
     "Can not copy" : "无法复制",
     "Copy link" : "复制链接",
-    "Enabled toggle of addressbook was not successful." : "启用切换地址簿未成功。",
-    "This will delete the addressbook and every contacts within it" : "这将删除地址簿及其中所有联系人",
     "Delete {addressbook} ?" : "删除 {addressbook} ？",
-    "Deletion of addressbook was not successful." : "未能成功删除地址簿。",
-    "Renaming of addressbook was not successful." : "未能成功重命名地址簿。",
-    "Addressbook copied to clipboard" : "地址簿已复制到剪贴板。",
-    "Addressbook was not copied to clipboard." : "地址簿未复制到剪贴板。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
     "Share with users or groups" : "和用户或者组群共享",
     "No users or groups" : "无用户或群组",
     "can edit" : "可编辑",
     "Unable to delete the share." : "无法删除此共享。",
     "Unable to change permissions." : "无法修改权限。",
-    "Importing into" : "导入到",
-    "Import into" : "导入到",
+    "Import contacts" : "导入联系人",
+    "Select local file" : "选择本地文件",
+    "Import from files" : "从文件导入",
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
+    "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Address book name" : "地址簿名称",
-    "An error occurred, unable to create the addressbook." : "发生了错误，地址簿未能成功创建。",
     "First name" : "名",
     "Last name" : "姓",
     "Display name" : "显示名称",
